@@ -3,10 +3,13 @@ from django.urls import path
 from drfpasswordless.views import (
     ObtainEmailCallbackToken,
     ObtainMobileCallbackToken,
-    ObtainAuthTokenFromCallbackToken,
-    VerifyAliasFromCallbackToken,
     ObtainEmailVerificationCallbackToken,
     ObtainMobileVerificationCallbackToken,
+    ObtainEmailChangeCallbackToken,
+    ObtainMobileChangeCallbackToken,
+    ObtainAuthTokenFromCallbackToken,
+    VerifyAliasFromCallbackToken,
+    ChangeAliasFromCallbackToken,
 )
 
 app_name = 'drfpasswordless'
@@ -24,4 +27,10 @@ urlpatterns = [
          ObtainMobileVerificationCallbackToken.as_view(), name='verify_mobile'),
     path(api_settings.PASSWORDLESS_VERIFY_PREFIX,
          VerifyAliasFromCallbackToken.as_view(), name='verify_token'),
+    path(api_settings.PASSWORDLESS_CHANGE_PREFIX + 'email/',
+         ObtainEmailChangeCallbackToken.as_view(), name='change_email'),
+    path(api_settings.PASSWORDLESS_CHANGE_PREFIX + 'mobile/',
+         ObtainMobileChangeCallbackToken.as_view(), name='change_mobile'),
+    path(api_settings.PASSWORDLESS_CHANGE_PREFIX,
+         ChangeAliasFromCallbackToken.as_view(), name='change_token'),
 ]
